/* GLOBAL PRODUCTION: FIRMS, CONTRACTS AND TRADE STRUCTURE */
/* CHAPTER 8 */
/* by Pol Antras, Harvard University, with the assistance of BooKang Seol. */
/* v 2.0.1, Last Updated: September 4th, 2014 */

version 13.1
set more off
capture log close
set matsize 2000

********************
* FILE DIRECTORIES *
********************
global root "C:/Users/Pol Antras/Documents/A_Active Papers/CREILectures/Data Programs Posted Online"
*Note the Users: change above line to the local directory where you downloaded the data and programs
cd "$root"
mkdir "$root/Tables_Ch8"
*Note the Users: run the two lines of code above before running the "log using" or "outreg commands" FOR THE FIRST TIME; these commands should then be silenced
global Tables "$root/Tables_Ch8"
log using "$Tables/analysis_chapter8_final"

*****************************
* BUILD CROSS-INDUSTRY DATA *
*****************************
** NAICS
cd "$root"
use "global_production_naics", clear
	// copy labels
foreach v of varlist imp_tot-kotherequip_pay{
 	local l`v' : variable label `v'
}
 
collapse (sum) imp* exp* (mean) dispersion-kotherequip_pay , by(naics year)

	// paste labels
foreach v of varlist imp_tot-kotherequip_pay {
 	label var `v' "`l`v''"
}

label data "Cross-Industry NAICS"
save "global_production_crossindustry_naics.dta", replace

** IO2002
use "global_production_io2002", clear

	// copy labels
foreach v of varlist imp_tot-flex{
 	local l`v' : variable label `v'
}
 
collapse (sum)imp* exp* (mean) discountm_gw-flex, by(io2002 year)
	
	// paste labels
foreach v of varlist imp_tot-flex{
 	label var `v' "`l`v''"
}

	// discount variables
drop discount* xt* 
ren i_discountm_gw discountm_gw
ren i_discountx_gw discountx_gw
ren i_discountm_gwnt discountm_gwnt
ren i_xtdiscountm_gw xtdiscountm_gw
ren i_xtdiscountx_gw xtdiscountx_gw

foreach var in discountm_gw discountx_gw discountm_gwnt xtdiscountm_gw xtdiscountx_gw {
replace `var'=0 if io2002=="331314" & `var'==.
}

label data "Cross-Industry IO2002"
*drop if io2002=="334411"
* Note to Users: the above line, when activated, allows one to check the robustness of the results to dropping industry IO334411, whose R&D intensity is an outlier

save "global_production_crossindustry_io2002.dta", replace

*************
* TABLE 8.3 *
*************
use "global_production_crossindustry_naics", clear
drop if naics=="33641X"
* Note to Users: See the Data Appendix for a justification for dropping the composite industry IO33641X

gen sif=imp_rel / (imp_rel+imp_non)
gen kl= log(cap / emp )
gen sl=log((emp-prode)/emp)
gen buildl=log(plant / emp )
gen equipl=log(equip / emp )
gen rd=log(0.001+ rd_complete)

* Note to Users: the outreg2 commands below produces spreadsheets with OLS estimates and beta coefficients. 
* The standard errors of the beta coefficients can be computed manually manipulating the spreadsheet.
* For other Tables, beta coefficients and standard errors are obtained more directly by first standardizing all variables.

** 8.3, col 1
areg sif rd sl kl, absorb(year) cluster(naics)
	outreg2 rd sl kl using "$Tables/Table8_3.xls", append se sym(**, *, +) ctitle(1) nocons dec(5)
	outreg2 rd sl kl using "$Tables/Table8_3.xls", append se noast ctitle(1) nocons dec(5)
	outreg2 rd sl kl using "$Tables/Table8_3.xls", append se noast stat(beta) ctitle(1beta) nocons dec(3)
** 8.3, col 2	
areg sif rd sl buildl equipl, absorb(year) cluster(naics)
	outreg2 rd sl buildl equipl using "$Tables/Table8_3.xls", append se sym(**, *, +) ctitle(2) nocons dec(5)
	outreg2 rd sl buildl equipl using "$Tables/Table8_3.xls", append se noast ctitle(2) nocons dec(5)
	outreg2 rd sl buildl equipl using "$Tables/Table8_3.xls", append se noast stat(beta) ctitle(2beta) nocons dec(3)
** 8.3, col 3	
areg sif rd sl buildl kautos kcomputer kotherequip , absorb(year) cluster(naics)
	outreg2 rd sl buildl kautos kcomputer kotherequip using "$Tables/Table8_3.xls", append se sym(**, *, +) ctitle(3) nocons dec(5)
	outreg2 rd sl buildl kautos kcomputer kotherequip using "$Tables/Table8_3.xls", append se noast ctitle(3) nocons dec(5)
	outreg2 rd sl buildl kautos kcomputer kotherequip using "$Tables/Table8_3.xls", append se noast stat(beta) ctitle(3beta) nocons dec(3)
** 8.3, col 4
areg sif rd sl buildl equipl tcosts tariff dispersion sigma , absorb(year) cluster(naics)
	outreg2 rd sl buildl equipl tcosts tariff dispersion sigma  using "$Tables/Table8_3.xls", append se sym(**, *, +) ctitle(4) nocons dec(5)	
	outreg2 rd sl buildl equipl tcosts tariff dispersion sigma  using "$Tables/Table8_3.xls", append se noast ctitle(4) nocons dec(5)
	outreg2 rd sl buildl equipl tcosts tariff dispersion sigma  using "$Tables/Table8_3.xls", append se noast stat(beta) ctitle(4beta) nocons dec(3)

* MOVE TO COUNTRY/INDUSTRY DATA FOR THE LAST TWO COLUMNS OF THE TABLE
use "global_production_naics", clear
drop if naics=="33641X"
drop if isocode=="SSD"
* Note to Users: See the Data Appendix for a justification for dropping the composite industry IO33641X and the country "SSD"
 
egen exp_tot_agg=sum(exp_tot), by(naics year)
egen imp_tot_agg=sum(imp_tot), by(naics year)
gen sif=imp_rel / (imp_rel+imp_non)

gen kl= log(cap / emp )
gen sl=log((emp-prode)/emp)
gen buildl=log(plant / emp )
gen equipl=log(equip / emp )
gen rd=log(0.001+ rd_complete)

egen ctyyear=group(isocode year)

** 8.3, col 5
areg sif rd sl buildl equipl tcosts tariff dispersion sigma , absorb(ctyyear) cluster(naics)
	outreg2 rd sl buildl equipl tcosts tariff dispersion sigma using "$Tables/Table8_3.xls", append se sym(**, *, +) ctitle(5) nocons dec(5)
	outreg2 rd sl buildl equipl tcosts tariff dispersion sigma using "$Tables/Table8_3.xls", append se noast ctitle(5) nocons dec(5)
	outreg2 rd sl buildl equipl tcosts tariff dispersion sigma using "$Tables/Table8_3.xls", append se noast stat(beta) ctitle(5beta) nocons dec(3)
** 8.3, col 6
areg sif rd sl buildl equipl tcosts tariff dispersion sigma  [aw=imp_tot], absorb(ctyyear) cluster(naics)
	outreg2 rd sl buildl equipl tcosts tariff dispersion sigma using "$Tables/Table8_3.xls", append se sym(**, *, +) ctitle(6) nocons dec(5)
	outreg2 rd sl buildl equipl tcosts tariff dispersion sigma using "$Tables/Table8_3.xls", append se noast ctitle(6) nocons dec(5)
	outreg2 rd sl buildl equipl tcosts tariff dispersion sigma using "$Tables/Table8_3.xls", append se noast stat(beta) ctitle(6beta) nocons dec(3)

*************
* TABLE 8.4 *
*************
use "global_production_crossindustry_io2002", clear

gen sif=imp_rel / (imp_rel+imp_non)
gen sif_gw_n=imp_rel_gw/( imp_rel_gw+ imp_non_gw)
gen sif_gw_nnt=imp_rel_gwnt / (imp_rel_gwnt +imp_non_gwnt)

gen kl= log(cap / emp )
gen sl=log((emp-prode)/emp)
gen buildl=log(plant /emp )
gen equipl=log(equip /emp )

gen wkl= log(wcap / wemp )
gen wsl=log((wemp-wprode)/wemp)
gen wbuildl=log(wplant / wemp )
gen wequipl=log(wequip / wemp )

gen extra_gw_drop=0
replace extra_gw_drop=1 if io2002=="325411" | io2002=="33299B"

** 8.4, col 1
areg sif rd sl buildl equipl tcosts tariff dispersion sigma, absorb(year) cluster(io2002)
	outreg2 rd sl buildl equipl tcosts tariff dispersion sigma using "$Tables/Table8_4.xls", append se sym(**, *, +) ctitle(1) nocons dec(10)
	outreg2 rd sl buildl equipl tcosts tariff dispersion sigma using "$Tables/Table8_4.xls", append se noast ctitle(1) nocons dec(10)
	outreg2 rd sl buildl equipl tcosts tariff dispersion sigma using "$Tables/Table8_4.xls", append se noast stat(beta) ctitle(1beta) nocons dec(3)
** 8.4, col 2
areg sif wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma, absorb(year) cluster(io2002)
	outreg2 wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma using "$Tables/Table8_4.xls", append se sym(**, *, +) ctitle(2) nocons dec(10)
	outreg2 wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma using "$Tables/Table8_4.xls", append se noast ctitle(2) nocons dec(10)
	outreg2 wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma using "$Tables/Table8_4.xls", append se noast stat(beta) ctitle(2beta) nocons dec(3)
** 8.4, col 3
areg sif_gw_n wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma if xtdiscountm_gw>0 & extra_gw_drop==0, absorb(year) cluster(io2002)
	outreg2 wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma using "$Tables/Table8_4.xls", append se sym(**, *, +) ctitle(3) nocons dec(10)
	outreg2 wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma using "$Tables/Table8_4.xls", append se noast ctitle(3) nocons dec(10)
	outreg2 wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma using "$Tables/Table8_4.xls", append se noast stat(beta) ctitle(3beta) nocons dec(3)
** 8.4, col 4
areg sif_gw_nnt wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma if xtdiscountm_gw>0 & extra_gw_drop==0, absorb(year) cluster(io2002)
	outreg2 wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma using "$Tables/Table8_4.xls", append se sym(**, *, +) ctitle(4) nocons dec(10)
	outreg2 wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma using "$Tables/Table8_4.xls", append se noast ctitle(4) nocons dec(10)
	outreg2 wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma using "$Tables/Table8_4.xls", append se noast stat(beta) ctitle(4beta) nocons dec(3)

* MOVE TO COUNTRY/INDUSTRY FOR FIXED EFFECTS
use "global_production_io2002", clear
*drop if io2002=="334411"

gen sif=imp_rel / (imp_rel+imp_non)
gen sif_gw_n=imp_rel_gw/( imp_rel_gw+ imp_non_gw)
gen sif_gw_nnt=imp_rel_gwnt / (imp_rel_gwnt +imp_non_gwnt)

gen kl= log(cap / emp )
gen sl=log((emp-prode)/emp)
gen buildl=log(plant /emp )
gen equipl=log(equip /emp )

gen wkl= log(wcap / wemp )
gen wsl=log((wemp-wprode)/wemp)
gen wbuildl=log(wplant / wemp )
gen wequipl=log(wequip / wemp )

egen ctyyear=group(isocode year)

gen extra_gw_drop=0
replace extra_gw_drop=1 if io2002=="325411" | io2002=="33299B"
drop if isocode=="SSD"

** 8.4, col 5
areg sif_gw_nnt wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma if xtdiscountm_gw>0 & extra_gw_drop==0, absorb(ctyyear) cluster(io2002)
	outreg2 wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma using "$Tables/Table8_4.xls", append se sym(**, *, +) ctitle(5) nocons dec(10)
	outreg2 wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma using "$Tables/Table8_4.xls", append se noast ctitle(5) nocons dec(10)
	outreg2 wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma using "$Tables/Table8_4.xls", append se noast stat(beta) ctitle(5beta) nocons dec(3)
** 8.4, col 6
areg sif_gw_nnt wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma [aw=imp_tot] if xtdiscountm_gw>0 & extra_gw_drop==0, absorb(ctyyear) cluster(io2002)
	outreg2 wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma using "$Tables/Table8_4.xls", append se sym(**, *, +) ctitle(6) nocons dec(10)
	outreg2 wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma using "$Tables/Table8_4.xls", append se noast ctitle(6) nocons dec(10)
	outreg2 wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma using "$Tables/Table8_4.xls", append se noast stat(beta) ctitle(6beta) nocons dec(3)


*************
* TABLE 8.6 *
*************
use "global_production_crossindustry_io2002", clear

gen sif=imp_rel / (imp_rel+imp_non)
gen sif_gw_n=imp_rel_gw/( imp_rel_gw+ imp_non_gw)
gen sif_gw_nnt=imp_rel_gwnt / (imp_rel_gwnt +imp_non_gwnt)

gen kl= log(cap / emp )
gen sl=log((emp-prode)/emp)
gen buildl=log(plant /emp )
gen equipl=log(equip /emp )

gen wkl= log(wcap / wemp )
gen wsl=log((wemp-wprode)/wemp)
gen wbuildl=log(wplant / wemp )
gen wequipl=log(wequip / wemp )

gen extra_gw_drop=0
replace extra_gw_drop=1 if io2002=="325411" | io2002=="33299B"

* STANDARDIZE VARIABLES
keep if xtdiscountm_gw>0 & extra_gw_drop==0
keep if sif_gw_nnt~=.

local varlist sif_gw_nnt wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma ext_dep tang nunn_c lev_c cos_c bjrs_c nunn_s input_subst 
foreach x of local varlist { 
	egen mean_`x' = mean(`x')
	egen sd_`x' = sd(`x')
	replace `x' = (`x' - mean_`x')/sd_`x'
	cap drop mean_`x' sd_`x'
	}

** 8.6, col 1 
foreach x in ext_dep tang nunn_c lev_c cos_c bjrs_c nunn_s input_subst {
areg sif_gw_nnt wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma `x', absorb(year) cluster(io2002)
	outreg2 using "$Tables/Table8_6_col1-3.xls", append se nocons ctitle(1) sym(**, *, +) dec(3) keep(`x')
}


	

** 8.6, col 4
areg sif_gw_nnt wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma ext_dep nunn_c nunn_s input_subst, absorb(year) cluster(io2002)
	outreg2 using "$Tables/Table8_6_col4-6.xls", append se nocons dec(3) ctitle(4) sym(**, *, +) keep(ext_dep nunn_c nunn_s input_subst)

	
* MOVE TO COUNTRY/INDUSTRY FOR FIXED EFFECTS
use "global_production_io2002", clear
*drop if io2002=="334411"

gen sif=imp_rel / (imp_rel+imp_non)
gen sif_gw_n=imp_rel_gw/( imp_rel_gw+ imp_non_gw)
gen sif_gw_nnt=imp_rel_gwnt / (imp_rel_gwnt +imp_non_gwnt)

gen kl= log(cap / emp )
gen sl=log((emp-prode)/emp)
gen buildl=log(plant /emp )
gen equipl=log(equip /emp )

gen wkl= log(wcap / wemp )
gen wsl=log((wemp-wprode)/wemp)
gen wbuildl=log(wplant / wemp )
gen wequipl=log(wequip / wemp )

egen ctyyear=group(isocode year)
drop if isocode=="SSD"

gen extra_gw_drop=0
replace extra_gw_drop=1 if io2002=="325411" | io2002=="33299B"

keep if xtdiscountm_gw>0 & extra_gw_drop==0

* STANDARDIZE VARIABLES
keep if xtdiscountm_gw>0 & extra_gw_drop==0
keep if sif_gw_nnt~=.

local varlist sif_gw_nnt wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma ext_dep tang nunn_c lev_c cos_c bjrs_c nunn_s input_subst
foreach x of local varlist { 
	egen mean_`x' = mean(`x')
	egen sd_`x' = sd(`x')
	replace `x' = (`x' - mean_`x')/sd_`x'
	cap drop mean_`x' sd_`x'
	}

** 8.6, col 2
foreach x in ext_dep tang nunn_c lev_c cos_c bjrs_c nunn_s input_subst {
areg sif_gw_nnt wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma `x', absorb(ctyyear) cluster(io2002)
	outreg2 using "$Tables/Table8_6_col1-3.xls", append se nocons sym(**, *, +) ctitle(2) dec(3) keep(`x')
}

** 8.6, col 5
areg sif_gw_nnt wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma ext_dep nunn_c nunn_s input_subst, absorb(ctyyear) cluster(io2002)
	outreg2 using "$Tables/Table8_6_col4-6.xls", append se nocons sym(**, *, +) dec(3) ctitle(5) keep(ext_dep nunn_c nunn_s input_subst)

* WEIGHING REGRESSIONS
** 8.6, col 3
foreach x in ext_dep tang nunn_c lev_c cos_c bjrs_c nunn_s input_subst {
areg sif_gw_nnt wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma `x' [aw=imp_tot], absorb(ctyyear) cluster(io2002)
	outreg2 using "$Tables/Table8_6_col1-3.xls", append se  nocons ctitle(3) sym(**, *, +) dec(3) keep(`x')
}

** 8.6, col 6
areg sif_gw_nnt wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma ext_dep nunn_c nunn_s input_subst [aw=imp_tot], absorb(ctyyear) cluster(io2002)
	outreg2 using "$Tables/Table8_6_col4-6.xls", append se nocons sym(**, *, +) dec(3) ctitle(6) keep(ext_dep nunn_c nunn_s input_subst)
	
	
*************
* TABLE 8.7 *
*************
use "global_production_crossindustry_io2002", clear

gen sif=imp_rel / (imp_rel+imp_non)
gen sif_gw_n=imp_rel_gw/( imp_rel_gw+ imp_non_gw)
gen sif_gw_nnt=imp_rel_gwnt / (imp_rel_gwnt+imp_non_gwnt)

gen kl= log(cap / emp )
gen sl=log((emp-prode)/emp)
gen buildl=log(plant /emp )
gen equipl=log(equip /emp )

gen wkl= log(wcap / wemp )
gen wsl=log((wemp-wprode)/wemp)
gen wbuildl=log(wplant / wemp )
gen wequipl=log(wequip / wemp )

gen down_lowsigma=wlowsigma*downmeasure
gen down_highsigma=whighsigma*downmeasure

gen extra_gw_drop=0
replace extra_gw_drop=1 if io2002=="325411" | io2002=="33299B"

* STANDARDIZE VARIABLES
keep if xtdiscountm_gw>0 & extra_gw_drop==0
keep if sif_gw_nnt~=.

local varlist sif_gw_nnt wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma ext_dep input_subst down_lowsigma down_highsigma wlowsigma nunn_c nunn_s wnunn_c wnunn_s
foreach x of local varlist { 
	egen mean_`x' = mean(`x')
	egen sd_`x' = sd(`x')
	replace `x' = (`x' - mean_`x')/sd_`x'
	cap drop mean_`x' sd_`x'
	}

** COLUMNS ONE, THREE AND FIVE Of TABLE 8.7 
** 8.7, col 1
areg sif_gw_nnt wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma ext_dep input_subst down_lowsigma down_highsigma wlowsigma nunn_c nunn_s , absorb(year) cluster(io2002)
	outreg2 using "$Tables/Table8_7_col135.xls", append se nocons sym(**, *, +) dec(3) ctitle(1) keep(down_highsigma down_lowsigma nunn_c nunn_s)
** 8.7, col 3
areg sif_gw_nnt wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma ext_dep input_subst down_lowsigma down_highsigma wlowsigma nunn_c wnunn_c nunn_s , absorb(year) cluster(io2002)
	outreg2 using "$Tables/Table8_7_col135.xls", append se nocons sym(**, *, +)dec(3) ctitle(3) keep(down_highsigma down_lowsigma nunn_c wnunn_c nunn_s)
** 8.7, col 5
areg sif_gw_nnt wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma ext_dep input_subst down_lowsigma down_highsigma wlowsigma nunn_c nunn_s wnunn_s, absorb(year) cluster(io2002)
	outreg2 using "$Tables/Table8_7_col135.xls", append se nocons sym(**, *, +) dec(3) ctitle(5) keep(down_highsigma down_lowsigma nunn_c nunn_s wnunn_s)

* MOVE TO COUNTRY/INDUSTRY FOR FIXED EFFECTS
use "global_production_io2002", clear
*drop if io2002=="334411"

gen sif=imp_rel / (imp_rel+imp_non)
gen sif_gw_n=imp_rel_gw/( imp_rel_gw+ imp_non_gw)
gen sif_gw_nnt=imp_rel_gwnt / (imp_rel_gwnt+imp_non_gwnt)

gen kl= log(cap / emp )
gen sl=log((emp-prode)/emp)
gen buildl=log(plant /emp )
gen equipl=log(equip /emp )

gen wkl= log(wcap / wemp )
gen wsl=log((wemp-wprode)/wemp)
gen wbuildl=log(wplant / wemp )
gen wequipl=log(wequip / wemp )

egen ctyyear=group(isocode year)
drop if isocode=="SSD"

gen down_lowsigma=wlowsigma*downmeasure
gen down_highsigma=whighsigma*downmeasure

gen extra_gw_drop=0
replace extra_gw_drop=1 if io2002=="325411" | io2002=="33299B"

keep if xtdiscountm_gw>0 & extra_gw_drop==0

* STANDARDIZE VARIABLES
keep if xtdiscountm_gw>0 & extra_gw_drop==0
keep if sif_gw_nnt~=.

local varlist sif_gw_nnt wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma ext_dep input_subst down_lowsigma down_highsigma wlowsigma nunn_c nunn_s wnunn_c wnunn_s
foreach x of local varlist { 
	egen mean_`x' = mean(`x')
	egen sd_`x' = sd(`x')
	replace `x' = (`x' - mean_`x')/sd_`x'
	cap drop mean_`x' sd_`x'
	}

* WEIGHING REGRESSIONS 
** 8.7, col 2
areg sif_gw_nnt wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma ext_dep input_subst down_lowsigma down_highsigma wlowsigma nunn_c nunn_s [aw=imp_tot], absorb(ctyyear) cluster(io2002)
	outreg2 using "$Tables/Table8_7_col246.xls", append se nocons sym(**, *, +) dec(3) ctitle(2) keep(down_highsigma down_lowsigma nunn_c nunn_s)
** 8.7, col 4
areg sif_gw_nnt wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma ext_dep input_subst down_lowsigma down_highsigma wlowsigma nunn_c wnunn_c nunn_s [aw=imp_tot], absorb(ctyyear) cluster(io2002)
	outreg2 using "$Tables/Table8_7_col246.xls", append se nocons sym(**, *, +) dec(3) ctitle(4) keep(down_highsigma down_lowsigma nunn_c wnunn_c nunn_s)
** 8.7, col 6
areg sif_gw_nnt wrd wsl wbuildl wequipl tcosts tariff dispersion wsigma ext_dep input_subst down_lowsigma down_highsigma wlowsigma nunn_c nunn_s wnunn_s [aw=imp_tot], absorb(ctyyear) cluster(io2002)
	outreg2 using "$Tables/Table8_7_col246.xls", append se nocons sym(**, *, +) dec(3) ctitle(6) keep(down_highsigma down_lowsigma nunn_c nunn_s wnunn_s)

	
*************
* TABLE 8.8 *
*************
use "global_production_io2002", clear
drop if isocode=="SSD"
*drop if io2002=="334411"

gen sif=imp_rel / (imp_rel+imp_non)
gen sif_gw_n=imp_rel_gw/( imp_rel_gw+ imp_non_gw)
gen sif_gw_nnt=imp_rel_gwnt / (imp_rel_gwnt+imp_non_gwnt)
gen log_sif_gw_nnt=log(imp_rel_gwnt / (imp_rel_gwnt+imp_non_gwnt))
gen log_ratioif_gw_nnt=log(imp_rel_gwnt / (imp_non_gwnt))

gen kl= log(cap / emp )
gen sl=log((emp-prode)/emp)


* GENERATE INTERACTIONS
gen k_k=kl*lK_L
gen s_s=sl*log(yr_sch)

gen nunn_rule=nunn_c*rule_of_law
gen lev_rule=lev_c*rule_of_law
gen bjrs_rule=bjrs_c*rule_of_law
gen cos_rule=cos_c*rule_of_law
gen cos_s=cos_c*log(yr_sch)
gen rz=ext_dep*log(private_credit)
gen braun=tang*log(private_credit)
gen svol_flex=sales_vol*flex

gen nunn_gdp_inter1=nunn_c*log(rgdpch)
gen lev_gdp_inter1=lev_c*log(rgdpch)
gen bjrs_gdp_inter1=bjrs_c*log(rgdpch)
gen cos_gdp_inter1=cos_c*log(rgdpch)
gen rz_gdp_inter1=rz*log(rgdpch)
gen braun_gdp_inter1=tang*log(rgdpch)
gen svol_gdp_inter1=sales_vol*log(rgdpch)

egen ctyyear=group(isocode year)
egen ctyind=group (isocode io2002)

* CREATING INTERACTIONS OF SECTOR DUMMIES WITH GDP
quietly tab io2002, ge(sectdum)
foreach i of numlist 1/253{
gen sectdum_gdp`i'=sectdum`i'*log(rgdpch)
}


gen extra_gw_drop=0
replace extra_gw_drop=1 if io2002=="325411" | io2002=="33299B"

keep if xtdiscountm_gw>0 & extra_gw_drop==0

** 8.8, col 1
xi: areg log_ratioif_gw_nnt i.io2002  k_k s_s [aw=imp_tot], absorb(ctyyear) cluster(ctyind)
	outreg2 k_k s_s using "$Tables/Table8_8.xls", append se sym(**, *, +) ctitle(1) nocons dec(10)
	outreg2 k_k s_s using "$Tables/Table8_8.xls", append se noast ctitle(1) nocons dec(10)
	outreg2 k_k s_s using "$Tables/Table8_8.xls", append se sym(**, *, +) stat(beta) ctitle(1beta) nocons dec(3)

** 8.8, col 2
foreach x in "nunn_rule" "lev_rule" "cos_rule cos_s" "bjrs_rule" "rz" "braun" "svol_flex" {
xi: areg log_ratioif_gw_nnt i.io2002  k_k s_s `x'  [aw=imp_tot], absorb(ctyyear) cluster(ctyind)
	outreg2 `x' using "$Tables/Table8_8.xls", append se sym(**, *, +) ctitle(2) nocons dec(10)
	outreg2 `x' using "$Tables/Table8_8.xls", append se noast ctitle(2) nocons dec(10)
	outreg2 `x' using "$Tables/Table8_8.xls", append se sym(**, *, +) stat(beta) ctitle(2beta) nocons dec(3)
}

** 8.8, col 3
xi: areg log_ratioif_gw_nnt i.io2002  k_k s_s nunn_rule lev_rul cos_rule cos_s bjrs_rule rz braun svol_flex [aw=imp_tot], absorb(ctyyear) cluster(ctyind)
	outreg2 k_k s_s nunn_rule lev_rul cos_rule bjrs_rule rz braun svol_flex using "$Tables/Table8_8.xls", append se sym(**, *, +) ctitle(3) nocons dec(10)
	outreg2 k_k s_s nunn_rule lev_rul cos_rule bjrs_rule rz braun svol_flex using "$Tables/Table8_8.xls", append se noast ctitle(3) nocons dec(10)
	outreg2 k_k s_s nunn_rule lev_rul cos_rule bjrs_rule rz braun svol_flex using "$Tables/Table8_8.xls", append se sym(**, *, +) stat(beta) ctitle(3beta) nocons dec(3)

** 8.8, col 4
xi: areg log_ratioif_gw_nnt i.io2002 *gdp_inter1 k_k s_s nunn_rule lev_rul cos_rule cos_s bjrs_rule rz braun svol_flex [aw=imp_tot], absorb(ctyyear) cluster(ctyind)
	outreg2 k_k s_s nunn_rule lev_rul cos_rule bjrs_rule rz braun svol_flex using "$Tables/Table8_8.xls", append se sym(**, *, +) ctitle(4) nocons dec(10)
	outreg2 k_k s_s nunn_rule lev_rul cos_rule bjrs_rule rz braun svol_flex using "$Tables/Table8_8.xls", append se noast ctitle(4) nocons dec(10)
	outreg2 k_k s_s nunn_rule lev_rul cos_rule bjrs_rule rz braun svol_flex using "$Tables/Table8_8.xls", append se sym(**, *, +) stat(beta) ctitle(4beta) nocons dec(3)

** 8.8, col 5
xi: areg log_ratioif_gw_nnt i.io2002 sectdum_gdp* k_k s_s nunn_rule lev_rul cos_rule cos_s bjrs_rule rz braun svol_flex [aw=imp_tot], absorb(ctyyear) cluster(ctyind)
	outreg2 k_k s_s nunn_rule lev_rul cos_rule bjrs_rule rz braun svol_flex using "$Tables/Table8_8.xls", append se sym(**, *, +) ctitle(5) nocons dec(10)
	outreg2 k_k s_s nunn_rule lev_rul cos_rule bjrs_rule rz braun svol_flex using "$Tables/Table8_8.xls", append se noast ctitle(5) nocons dec(10)
	outreg2 k_k s_s nunn_rule lev_rul cos_rule bjrs_rule rz braun svol_flex using "$Tables/Table8_8.xls", append se sym(**, *, +) stat(beta) ctitle(5beta) nocons dec(3)

*************
* TABLE 8.9 *
*************
use "global_production_io2002", clear
drop if isocode=="SSD"
*drop if io2002=="334411"

gen sif=imp_rel / (imp_rel+imp_non)
gen sif_gw_n=imp_rel_gw/( imp_rel_gw+ imp_non_gw)
gen sif_gw_nnt=imp_rel_gwnt / (imp_rel_gwnt+imp_non_gwnt)
gen log_sif_gw_nnt=log(imp_rel_gwnt / (imp_rel_gwnt+imp_non_gwnt))
gen log_ratioif_gw_nnt=log(imp_rel_gwnt / (imp_non_gwnt))

gen kl= log(cap / emp )
gen sl=log((emp-prode)/emp)

gen wkl= log(wcap / wemp )
gen wsl=log((wemp-wprode)/wemp)
gen wequipl=log(wequip / wemp )

pca wequipl wsl wrd
predict whead wheadscore

* GENERATE INTERACTIONS
gen k_k=kl*lK_L
gen s_s=sl*log(yr_sch)

gen input_subst_rule=input_subst*rule_of_law
gen wsigma_rule=wsigma*rule_of_law
gen nunns_rule=nunn_s*rule_of_law
gen whead_dev=whead*private_credit
gen whead_rule=whead*rule_of_law
gen extdep_rule=ext_dep*rule_of_law
gen tang_rule=tang*rule_of_law

gen input_subst_gdp_inter2=input_subst*log(rgdpch)
gen wsigma_gdp_inter2=wsigma*log(rgdpch)
gen nunns_gdp_inter2=nunns*log(rgdpch)
gen whead_gdp_inter2=whead*log(rgdpch)

egen ctyyear=group(isocode year)
egen ctyind=group (isocode io2002)


* CREATING INTERACTIONS OF SECTOR DUMMIES WITH GDP
quietly tab io2002, ge(sectdum)
foreach i of numlist 1/253{
gen sectdum_gdp`i'=sectdum`i'*log(rgdpch)
}


gen extra_gw_drop=0
replace extra_gw_drop=1 if io2002=="325411" | io2002=="33299B"

keep if xtdiscountm_gw>0 & extra_gw_drop==0

** 8.9, col 1
xi: areg log_ratioif_gw_nnt i.io2002 k_k s_s tc tar [aw=imp_tot], absorb(ctyyear) cluster(ctyind)
	outreg2 tc tar using "$Tables/Table8_9.xls", append se sym(**, *, +) ctitle(1) nocons dec(10)
	outreg2 tc tar using "$Tables/Table8_9.xls", append se noast ctitle(1) nocons dec(10)
	outreg2 tc tar using "$Tables/Table8_9.xls", append se sym(**, *, +) stat(beta) ctitle(1beta) nocons dec(3)
** 8.9, col 2
foreach x in input_subst_rule wsigma_rule nunns_rule whead_dev whead_rule{
xi: areg log_ratioif_gw_nnt i.io2002  k_k s_s tc tar `x' [aw=imp_tot], absorb(ctyyear) cluster(ctyind)
	outreg2 `x' using "$Tables/Table8_9.xls", append se sym(**, *, +) ctitle(2) nocons dec(10)
	outreg2 `x' using "$Tables/Table8_9.xls", append se noast ctitle(2) nocons dec(10)
	outreg2 `x' using "$Tables/Table8_9.xls", append se sym(**, *, +) stat(beta) ctitle(2beta) nocons dec(3)
}
 
** 8.9, col 3
xi: areg log_ratioif_gw_nnt i.io2002 k_k s_s tc tar input_subst_rule wsigma_rule nunns_rule whead_dev whead_rule [aw=imp_tot], absorb(ctyyear) cluster(ctyind)
	outreg2 tc tar input_subst_rule wsigma_rule nunns_rule whead_dev whead_rule using "$Tables/Table8_9.xls", append se sym(**, *, +) ctitle(3) nocons dec(10)
	outreg2 tc tar input_subst_rule wsigma_rule nunns_rule whead_dev whead_rule using "$Tables/Table8_9.xls", append se noast ctitle(3) nocons dec(10)
	outreg2 tc tar input_subst_rule wsigma_rule nunns_rule whead_dev whead_rule using "$Tables/Table8_9.xls", append se sym(**, *, +) stat(beta) ctitle(3beta) nocons dec(3)
** 8.9, col 4
xi: areg log_ratioif_gw_nnt i.io2002 *gdp_inter2 k_k s_s tc tar input_subst_rule wsigma_rule nunns_rule whead_dev whead_rule [aw=imp_tot], absorb(ctyyear) cluster(ctyind)
	outreg2 tc tar input_subst_rule wsigma_rule nunns_rule whead_dev whead_rule using "$Tables/Table8_9.xls", append se sym(**, *, +) ctitle(4) nocons dec(10)
	outreg2 tc tar input_subst_rule wsigma_rule nunns_rule whead_dev whead_rule using "$Tables/Table8_9.xls", append se noast ctitle(4) nocons dec(10)
	outreg2 tc tar input_subst_rule wsigma_rule nunns_rule whead_dev whead_rule using "$Tables/Table8_9.xls", append se sym(**, *, +) stat(beta) ctitle(4beta) nocons dec(3)					 
** 8.9, col 5
xi: areg log_ratioif_gw_nnt i.io2002 sectdum_gdp* k_k s_s tc tar input_subst_rule wsigma_rule nunns_rule whead_dev whead_rule [aw=imp_tot], absorb(ctyyear) cluster(ctyind)
	outreg2 tc tar input_subst_rule wsigma_rule nunns_rule whead_dev whead_rule using "$Tables/Table8_9.xls", append se sym(**, *, +) ctitle(5) nocons dec(10)
	outreg2 tc tar input_subst_rule wsigma_rule nunns_rule whead_dev whead_rule using "$Tables/Table8_9.xls", append se noast ctitle(5) nocons dec(10)
	outreg2 tc tar input_subst_rule wsigma_rule nunns_rule whead_dev whead_rule using "$Tables/Table8_9.xls", append se sym(**, *, +) stat(beta) ctitle(5beta) nocons dec(3)

*******
log close
exit
